// URL Lock

//
// This file contains the code for the main rule editing window
//

// The currently-selected rule
var rule;

/**
 * Select all users
 */
function selectAll() {
	var users = lockEngine.getConfiguration().getUsers();

	for (i=0;i<users.length;i++) {
		document.getElementById('blockUsers').getItemAtIndex(i).checked=true;
	}
}

/**
 * Unselect all users
 */
function clearAll() {
	var users = lockEngine.getConfiguration().getUsers();
	
	for (i=0;i<users.length;i++) {
		document.getElementById('blockUsers').getItemAtIndex(i).checked=false;
	}
}

function addNew() {
	window.open("chrome://urllock/content/urlAddNew.xul", "Add New List", "chrome");
}

function advancedOption() {
	window.open("chrome://urlLock/content/advancedOption.xul", "Advanced", "chrome");
}

/**
 * Saves the changes to this rule
 */
function saveSelection() {
    if (rule == null) {
        return;
    }
	rule.setDomain(document.getElementById('selectURL').value);
	handleUserSelection();
	rule.save();
}

/**
 * Closes the window
 */
function cancelSelection() {
	this.close();
}

/**
 * Deletes the current rule
 */
function deleteSelection() {
    if (rule == null) {
        return;
    }
    
    // Remove the rule from the model
    lockEngine.getConfiguration().removeRule(rule);
    
    // We no longer have an active rule
    rule = null;
    
    // Now that the rule is deleted, we cannot select users until a rule is selected
    refreshEditor();
}

/**
 * Called when the window loads
 */
function init() {
	initUserList();
	
	// Delay the execution of initURLList() to work around an update bug
	// in the user list
	myTime = setTimeout("initURLList()", 1);
}

/**
 * Populates the URL block list
 */
function initURLList() {
	
	// Remove the existing rules from the GUI, if any
	var rules = document.getElementById('urlList');
	var i;
	for (i = rules.getRowCount() - 1; i >= 0; i--) {
	    rules.removeItemAt(i);
	}
	
	// Add the rules
	var rulesList = lockEngine.getConfiguration().getRules();
	var ruleItem;
	var selected = false;
	for (i = 0; i < rulesList.length; i++) {
		ruleItem = rules.appendItem(rulesList.item(i).getDomain(), rulesList.item(i).getRuleID());
		
		// If this was the rule that was selected, then be sure that this one is selected
		if (rulesList.item(i) == rule) {
		    rules.selectItem(ruleItem);
		    selected = true;
		}
	}
	
	// If we didn't select anything, then select the first item, if one exists
	if (!selected && rulesList.length > 0) {
	    rules.selectItem(rules.getItemAtIndex(0));
	}
}

/**
 * Loads the user list upon the selection of a rule
 */
function loadBlockList() {

    // If we have a selection, then get the selected rule and proceed
    var rules = document.getElementById('urlList');
	if (rules.selectedCount > 0) {
	    rule = lockEngine.getConfiguration().getRule(rules.selectedItem.value);

        // Now that we have a selected rule, users can be selected
        refreshEditor();
        if (rule == null) {
            return;
        }

		// Set the URL text box
		document.getElementById('selectURL').value = rule.getDomain();
		
		// Clear the user selection
		users = document.getElementById('blockUsers');
		var i, count = users.getRowCount();
		for (i = 0; i < count; i++) {
		    users.getItemAtIndex(i).checked = false;
		}
		
		// Select the users that are in this rule
		var ruleUsers = rule.getUsers();
		for (i = 0; i < ruleUsers.length; i++) {
		    document.getElementById("userlist-" + ruleUsers.item(i).getUserName()).checked = true;
		}
	}
}

/**
 * Populates the user list
 */
function initUserList() {

	// Remove the existing rules from the GUI, if any
	var users = document.getElementById('blockUsers');
	var i;
	for (i = users.getRowCount() - 1; i >= 0; i--) {
	    users.removeItemAt(i);
	}

	// Add the users in the system to the list
	var usersList = lockEngine.getConfiguration().getUsers();
	var user;
	for (i = 0; i < usersList.length; i++) {
		user = users.appendItem(usersList.item(i).getFullName(), usersList.item(i).getUserName());
		user.setAttribute("type","checkbox");
		user.setAttribute("id", "userlist-" + usersList.item(i).getUserName());
	}
	
	// Make the users disabled if no rule is selected
	refreshEditor();
}

/**
 * Search rules as a filter is typed in
 */
function textSearch() {

    // Delay the searching for 100 milliseconds
	myTime = setTimeout("searchText()", 100);
}

/**
 * Limits the rule list using the current filter
 */
function searchText() {
	var rules = document.getElementById('urlList');
	var rulesList = lockEngine.getConfiguration().getRules();

    // Remove the existing rules
	while (rules.getRowCount() > 0) {
		rules.removeItemAt(0);
	}

    // Filter the list to only those that contain the search string
	var searchString = document.getElementById('urlbox').value;
	var ruleItem, ruleSelected = false;
	for (i=0; i < rulesList.length;i++) {
		if (searchString.length==0 || rulesList.item(i).getDomain().indexOf(searchString)>=0) {
			ruleItem = rules.appendItem(rulesList.item(i).getDomain(), rulesList.item(i).getRuleID());
			
			// If this was the rule that was selected, then be sure that this one is selected
			if (rulesList.item(i) == rule) {
			    rules.selectItem(ruleItem);
			    ruleSelected = true;
			}
		}
	}
	
	// If our rule is no longer selected, then make it null
	if (!ruleSelected) {
	    rule = null;
	    refreshEditor();
	}
}

/**
 * Refreshes the editor by enabling or disabling components depending on
 * the current state
 */
function refreshEditor() {

    // Enable or disable the editor items depending on whether or not a rule is current
	if (rule == null) {
	    document.getElementById('blockUsers').setAttribute("disabled", true);
        document.getElementById('selectURL').setAttribute("disabled", true);
	} else {
	    document.getElementById('blockUsers').removeAttribute("disabled");
        document.getElementById('selectURL').removeAttribute("disabled");
    }
}

function allowAllPages() {
	
}

function disableAllPages() {
	
}

function alertOnDeny() {
	
}

function accessDenyOn() {
	
}

function restrictAll() {
	
}

/**
 * Handle the selection or deselection of the users
 */
function handleUserSelection() {
   
    // Handle each user in the list
    var users = document.getElementById('blockUsers');
    var i, count = users.getRowCount();
    var user, userItem;
    for (i = 0; i < count; i++) {

        // Get the user that this event applies to
        userItem = users.getItemAtIndex(i);
        user = lockEngine.getConfiguration().getUser(userItem.value);
   
        // Add or remove this user from this rule depending on the current
        // selected state
        if (userItem.checked) {
            rule.addUser(user);
        } else {
            rule.removeUser(user);
        }
    }
}

function openExplain() {
	window.open("chrome://urlLock/content/explaination.xul", "About", "chrome");
}
function openAbout() {
	window.open("chrome://urlLock/content/about.xul", "About", "chrome");
}
function openURLLock() {
	window.open("http://ieurllock.sourceforge.net/");	
}

// Called when the window is created
function urlLockHomeStartup() {

    // Register our change listener to re-initialize the entire window
    lockEngine.getConfiguration().wrappedJSObject.fieldChanged = function() {
        init();
    }
}

// Register a window load handler to register the lock configuration change handler
window.addEventListener("load", urlLockHomeStartup, false);
